@@ -6,6 +6,34 @@ import xlrd
 import xlwt
 from xlutils.copy import copy
 import numpy as np
+import orjson
+
+
+# import chardet
+# from chardet.universaldetector import UniversalDetector
+
+# TODO
+# import fairies as fa
+# import csv
+# from tqdm import tqdm
+# import chardet
+# from chardet.universaldetector import UniversalDetector
+
+# def get_encoding(file):
+#         detector = UniversalDetector()
+#         with open(file,'rb') as f:
+#             for line in f:
+#                 detector.feed(line)
+#                 if detector.done:
+#                     break
+#         detector.close()
+#         print(detector.result)        
+#         # return chardet.detect(f.read(1100))['encoding']
+
+# print(get_encoding("0325_3a_tj.csv"))
+
+
+
 
 
 class read_data():
@@ -53,17 +81,23 @@ class read_data():
 
         return res
 
+    # def read_json(self):
+        
+    #     try:
+    #         with open(self.fileName,'r', encoding='utf8') as f:
+    #             json_data = json.load(f)
+    #     except:
+    #         json_data = []
+    #         with open(self.fileName,encoding='utf-8') as f:
+    #             for line in tqdm(f):
+    #                 json_data.append(json.loads(line))        
+    #     return json_data    
+
     def read_json(self):
         
-        try:
-            with open(self.fileName,'r', encoding='utf8') as f:
-                json_data = json.load(f)
-        except:
-            json_data = []
-            with open(self.fileName,encoding='utf-8') as f:
-                for line in tqdm(f):
-                    json_data.append(json.loads(line))        
-        return json_data    
+        with open(self.fileName,'rb') as f:
+            json_data = orjson.loads(f.read())
+        return json_data
 
     def read_excel(self):
         
@@ -154,3 +188,9 @@ def read_npy(fileName):
 
     dict_load=np.load(fileName, allow_pickle=True)
     return dict_load.tolist()
+
+def read_orjson(fileName):
+        
+    with open(fileName,'rb') as f:
+        json_data = orjson.loads(f.read())
+    return json_data
\ No newline at end of file
